
import java.util.Scanner;

public class Hanoi {

    static class PegEmptyException extends Exception {
    };

    static class DiskTooBigException extends Exception {
    };

    static class DiskAlreadyThereException extends Exception {
    };

    static class WrongDiskSizeException extends Exception {
    };

    static class Peg {

        private int N;
        private int S[];
        private int top = -1;
        private HanoiPegs HP;
        private String label;

        Peg(int n, String l, HanoiPegs hp) {
            N = n;
            S = new int[n];
            HP = hp;
            label = l;
        }

        void push(int k) throws DiskTooBigException, DiskAlreadyThereException, WrongDiskSizeException {
            if (k < 1 || k > N) {
                throw new WrongDiskSizeException();
            }
            if (top >= 0 && k > S[top]) {
                throw new DiskTooBigException();
            }

            if (HP.contains(k)) {
                throw new DiskAlreadyThereException();
            }

            S[++top] = k;
        }

        int pop() throws PegEmptyException {
            if (top < 0) {
                throw new PegEmptyException();
            }
            return S[top--];
        }

        Boolean contains(int k) {
            for (int i = 0; i <= top; i++) {
                if (S[i] == k) {
                    return true;
                }
            }

            return false;
        }

        public String getLabel() {
            return label;
        }
    }

    static class HanoiPegs {

        Peg A, B, C;
        private int N;

        HanoiPegs(int n) {
            N = n;
            A = new Peg(N, "A", this);
            B = new Peg(N, "B", this);
            C = new Peg(N, "C", this);

            for (int i = n; i > 0; i--) {
                try {
                    A.push(i);
                } catch (DiskTooBigException ex) { // To się nie może zdarzyć
                } catch (DiskAlreadyThereException ex) { // To też się nie może zdarzyć
                } catch (WrongDiskSizeException ex) { // To również się nie może zdarzyć
                }
            }
        }

        Boolean contains(int k) {
            if (A.contains(k)) {
                return true;
            }
            if (B.contains(k)) {
                return true;
            }
            if (C.contains(k)) {
                return true;
            }

            return false;
        }
    }


    public static void main(String[] args) throws DiskTooBigException, WrongDiskSizeException, DiskAlreadyThereException, PegEmptyException {
        Scanner sc = new Scanner(System.in);
        System.out.println("Podaj liczbe krazkow:");
        int n = sc.nextInt();

        HanoiPegs pegs = new HanoiPegs(n);

        // Tu wstawić rozwiązanie

    }
}
